==> angelssmelting_0.3.5.zip: angelssmelting_0.3.5/prototypes/items/angels-cobalt.lua <==
data:extend(
{
  {
    type = "item",
    name = "cobalt-ore",
    icon = "__angelssmelting__/graphics/icons/ore-cobalt.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "processed-cobalt",
    icon = "__angelssmelting__/graphics/icons/processed-cobalt.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-cobalt",
    icon = "__angelssmelting__/graphics/icons/pellet-cobalt.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-cobalt-hydroxide",
    icon = "__angelssmelting__/graphics/icons/solid-cobalt-hydroxide.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-cobalt-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-cobalt-oxide.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "ingot-cobalt",
    icon = "__angelssmelting__/graphics/icons/ingot-cobalt.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-cobalt",
    icon = "__angelssmelting__/graphics/icons/powder-cobalt.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "g",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-molten-cobalt",
    icon = "__angelssmelting__/graphics/icons/molten-cobalt.png",
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
	auto_barrel = false
  },
  {
    type = "item",
    name = "angels-plate-cobalt",
    icon = "__angelssmelting__/graphics/icons/plate-cobalt.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt-casting",
    order = "h",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-roll-cobalt",
    icon = "__angelssmelting__/graphics/icons/roll-cobalt.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt-casting",
    order = "i",
    stack_size = 200
  },
}
)

==> angelssmelting_0.4.3.zip: angelssmelting_0.4.3/prototypes/items/angels-cobalt.lua <==
data:extend(
{
  {
    type = "item",
    name = "cobalt-ore",
    icon = "__angelssmelting__/graphics/icons/ore-cobalt.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "processed-cobalt",
    icon = "__angelssmelting__/graphics/icons/processed-cobalt.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-cobalt",
    icon = "__angelssmelting__/graphics/icons/pellet-cobalt.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-cobalt-hydroxide",
    icon = "__angelssmelting__/graphics/icons/solid-cobalt-hydroxide.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-cobalt-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-cobalt-oxide.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "ingot-cobalt",
    icon = "__angelssmelting__/graphics/icons/ingot-cobalt.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-cobalt",
    icon = "__angelssmelting__/graphics/icons/powder-cobalt.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt",
    order = "g",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-molten-cobalt",
    icon = "__angelssmelting__/graphics/icons/molten-cobalt.png",
	icon_size = 32,
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 51/255, g = 74/255, b = 109/255},
    flow_color = {r = 51/255, g = 74/255, b = 109/255},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
	auto_barrel = false
  },
  {
    type = "item",
    name = "angels-plate-cobalt",
    icon = "__angelssmelting__/graphics/icons/plate-cobalt.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt-casting",
    order = "h",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-roll-cobalt",
    icon = "__angelssmelting__/graphics/icons/roll-cobalt.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-cobalt-casting",
    order = "i",
    stack_size = 200
  },
}
)
